<?php
/**
 * Ippo functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Ippo
 */

if ( ! function_exists( 'ippo_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function ippo_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Ippo, use a find and replace
	 * to change 'ippo-shop' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'ippo-shop', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/**
	 * Enable WordPress theme logo functionality
	 */
	add_theme_support( 'custom-logo' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	/**
	 * Define image sizes
	 */
	add_image_size( 'ippo-archive-featured-image', 690, 999999, false );
	add_image_size( 'ippo-carousel-slider-image', 1317, 999999, false );
	add_image_size( 'ippo-sticky-featured-image', 800, 999999, false );
	add_image_size( 'ippo-single-featured-image', 1400, 999999, false );

	/**
	 * Increase image quality compression
	 */
	add_filter( 'jpeg_quality', function() {
		return 100;
	} );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary'     => esc_html__( 'Primary', 'ippo-shop' ),
		'social-menu' => esc_html__( 'Social Menu', 'ippo-shop' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Add Support for WooCommerce
	 */
	add_theme_support( 'woocommerce', array(
		'gallery_thumbnail_image_width' => 1024,
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'image',
		'gallery',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'ippo_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Add support for Woocommerce Gallery features: Image zoom / Magnification and Lightbox

	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );

}
endif;
add_action( 'after_setup_theme', 'ippo_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ippo_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ippo_content_width', 1400 );
}
add_action( 'after_setup_theme', 'ippo_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ippo_widgets_init() {

	// Define sidebars
	$sidebars = array(
		'sidebar-1'        => esc_html__( 'Sidebar', 'ippo-shop' ),
		'sidebar-shop'     => esc_html__( 'Shop Sidebar', 'ippo-shop' ),
		'footer-widgets-1' => esc_html__( 'Footer widgets 1', 'ippo-shop' ),
		'footer-widgets-2' => esc_html__( 'Footer widgets 2', 'ippo-shop' ),
		'footer-widgets-3' => esc_html__( 'Footer widgets 3', 'ippo-shop' ),
	);

	// Loop through each sidebar and register
	foreach ( $sidebars as $sidebar_id => $sidebar_name ) {
		register_sidebar( array(
			'name'          => $sidebar_name,
			'id'            => $sidebar_id,
			'description'   => sprintf( esc_html__( 'Widget area for %s', 'ippo-shop' ), $sidebar_name ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}

}
add_action( 'widgets_init', 'ippo_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function ippo_scripts() {
	// Load Thickbox style
	wp_enqueue_style( 'thickbox' );

	// Main theme stylesheet file
	wp_enqueue_style( 'ippo-style', get_stylesheet_uri() );

	// Woocommerce styling
	if ( ippo_is_woocommerce_activated() ) {
		wp_enqueue_style( 'ippo-woocommerce-style', get_template_directory_uri() . '/woo-style.css' );

		if ( is_rtl() ) {
			wp_enqueue_style( 'ippo-woocommerce-rtl-style', get_template_directory_uri() . '/woo-rtl.css' );
		}
	}

	// Front Slider Style

	$front_slider = get_theme_mod( 'front_page_slider_enable', 1 );

	if ( $front_slider ) :

		$slider_style = esc_html(ippo_front_slider_style());

		if ( ippo_is_woocommerce_activated() ) {
			wp_add_inline_style( 'ippo-woocommerce-style', $slider_style );
		}
		else {
			wp_add_inline_style( 'ippo-style', $slider_style );
		}

	endif;

	// Change Colors Style

	$change_colors_style = wp_strip_all_tags( ippo_change_colors() );

	if ( ippo_is_woocommerce_activated() ) {
		wp_add_inline_style( 'ippo-woocommerce-style', $change_colors_style );
	}
	else {
		wp_add_inline_style( 'ippo-style', $change_colors_style );
	}

	// Scripts

	wp_enqueue_script( 'ippo-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );
	wp_enqueue_script( 'slick-slider', get_template_directory_uri() . '/assets/js/slick/slick.min.js', array(), false, true );
	wp_enqueue_script( 'infinite-scroll', get_template_directory_uri() . '/assets/js/infinite-scroll/infinite-scroll.min.js', array( 'jquery', 'masonry' ), false, true );
	wp_enqueue_script( 'ippo-js-functions', get_template_directory_uri() . '/assets/js/common.js', array( 'masonry', 'thickbox' ), false, true );

	if ( ippo_is_woocommerce_activated() ) {
		if ( !is_home() && !is_archive() || is_shop() || is_woocommerce() ) {
			wp_enqueue_script( 'ippo-call-woo-scripts', get_template_directory_uri() . '/assets/js/woo-common.js', array( 'jquery' ), false, true );
		}
	}

	// Get and define JS vars
	global $wp_query;

	$max                  = $wp_query->max_num_pages;
	$paged                = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
	$infinite_scroll_type = get_theme_mod( 'infinite_scroll_type', 'click' );
	$paging_type          = get_theme_mod( 'paging_setting', 'infinite-scroll' );

	$js_vars = array(
		'url'                     => get_template_directory_uri(),
		'admin_url'               => esc_url( admin_url( 'admin-ajax.php' ) ),
		'nonce'                   => wp_create_nonce( 'ajax-nonce' ),
		'no_more_text'            => esc_html__( 'No more posts to load.', 'ippo-shop' ),
		'startPage'               => $paged,
		'maxPages'                => $max,
		'is_type'                 => $infinite_scroll_type,
		'paging_type'             => $paging_type
	);
	wp_localize_script( 'ippo-js-functions', 'js_vars', $js_vars );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'ippo_scripts' );

/**
 * Enqueue admin scripts
 */
function ippo_add_admin_scripts() {
	// Admin styles
	wp_enqueue_style( 'ippo-admin-css', get_template_directory_uri() . '/inc/admin/admin.css' );
	wp_enqueue_style( 'wp-color-picker' );

	// Admin scripts
	wp_enqueue_media();
	wp_enqueue_script( 'my-upload' );
	wp_enqueue_script( 'jquery-ui' );
	wp_enqueue_script( 'wp-color-picker' );
	wp_enqueue_script( 'ippo-admin-js', get_template_directory_uri() . '/inc/admin/admin.js' );

	$js_vars = array(
		'url'                     => get_template_directory_uri(),
		'admin_url'               => esc_url( admin_url( 'admin-ajax.php' ) ),
		'nonce'                   => wp_create_nonce( 'ajax-nonce' ),
		'default_text'            => esc_html__( 'Theme default', 'ippo-shop' )
	);
	wp_localize_script( 'ippo-admin-scripts', 'js_vars', $js_vars );
}
add_action( 'admin_enqueue_scripts', 'ippo_add_admin_scripts' );

/**
 * One click demo import settings
 */
function ippo_import_files() {
  return array(
    array(
      'import_file_name'           => 'ippo Shop Demo',
      'import_file_url'            => get_template_directory_uri().'/import/demo1/content.xml',
      'import_widget_file_url'     => get_template_directory_uri().'/import/demo1/widgets.json',
      'import_customizer_file_url' => get_template_directory_uri().'/import/demo1/customizer.dat',
      'import_preview_image_url'   => get_template_directory_uri().'/import/demo1/screenshot.png',
      'import_notice'              => __( 'You can speed up development of your site by importing our sample site content like posts and images. The imported images are copyrighted and are for demo use only. Please replace them with your own images after importing.', 'ippo-shop' ),
    ),
  );
}
add_filter( 'pt-ocdi/import_files', 'ippo_import_files' );

/**
 * Change theme color support
 */
require get_template_directory() . '/inc/change-colors.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load plugin activation script file.
 */
require get_template_directory() . '/inc/plugin-activation.php';

/**
 * Load Meta Boxes Config
 */
require get_template_directory() . '/inc/metadata/meta-boxes.php';


/**
 * Load WooCommerce theme functions.
 */
if ( ippo_is_woocommerce_activated() ) {
	require get_template_directory() . '/inc/apis/class-product-sorting-widget.php';
	require get_template_directory() . '/inc/woo-functions.php';
}
