<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Ippo
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 * @since Ippo 1.0
 */
function ippo_body_classes( $classes ) {

	// Get all customization values
	$sticky_header    = get_theme_mod( 'sticky_header_setting', 1 );
	$featured_slider  = get_theme_mod( 'front_page_slider_enable', 0 );
	$menu_type        = get_theme_mod( 'header_display_setting', 0 );
	$blog_layout      = get_theme_mod( 'blog_layout_setting', 'three-columns' );
	$paging_type      = get_theme_mod( 'paging_setting', 'infinite-scroll' );
	$widget_area_type = get_theme_mod( 'shop_sidebar_settings', 'default' );
	$portfolio_layout = get_theme_mod( 'portfolio_layout_setting', 'four-columns' );
	$shop_layout      = get_theme_mod( 'shop_layout_setting', 'three-columns' );

	if ( is_single() && ( 'product' == get_post_type() ) ) {

		$split_layout = get_post_meta( get_the_ID(), 'ippo_single_product_split', true );
		$product      = wc_get_product( get_the_ID() );

		if ( $split_layout && !$product->is_type( 'variable' ) ) {
			$classes[] = 'half-width-slider';
		}

	}

	if ( is_page_template( 'templates/template-portfolio.php' ) || is_tax( 'ct_portfolio' ) || is_post_type_archive( 'portfolio' ) ) {

		$classes[] = 'layout-' . $portfolio_layout;

	} else if ( ( ippo_is_woocommerce_activated() && ! is_shop() ) && ( is_home() || is_archive() || is_page_template( 'templates/template-headline.php' ) ) ) {

		$classes[] = 'layout-' . $blog_layout;

	}

	if ( ippo_is_woocommerce_activated() && ( is_shop() || is_archive() ) ) {

		$classes[] = 'shop-' . $shop_layout;

		if ( 'popup' == $widget_area_type ) {
			$classes[] = 'popup-widgets';
		}

	}

	if ( is_home() || is_tax( 'ct_portfolio' ) || is_archive() || is_page_template( 'templates/template-headline.php' ) || is_page_template( 'templates/template-portfolio.php' ) || is_post_type_archive('portfolio') ) {
		$classes[] = $paging_type;
	}

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of tk-theme-frontend when viewing frontend.
	if ( !is_admin() ) {
		$classes[] = 'tk-theme-frontend';
	}

	// Menu type class
	if ( $menu_type ) {
		$classes[] = 'hamburger-menu';
	} else {
		$classes[] = 'standard-menu';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( $sticky_header ) {
		$classes[] = 'sticky-header';
	}

	if ( $featured_slider && is_front_page() ) {

		$slides_number   = get_theme_mod( 'front_page_slider_slides', 5 );
		$slides_category = get_theme_mod( 'front_page_slider_category', 'default' );

		if ( 'default' != $slides_category ) {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
				'tax_query'      => array(
					'relation'   => 'AND',
						array(
							'taxonomy' => 'ct_slider',
							'field'    => 'slug',
							'terms'    => array( $slides_category ),
							'operator' => 'IN'
						),
				)
			);

		}
		else {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
			);

		}

		$front_slides = new WP_Query( $args );

		if ( $featured_slider && is_front_page() && $front_slides->have_posts() ) {
			$classes[] = 'fullwidth-slider';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'ippo_body_classes' );

/**
 * Display content classes
 *
 * @since Ippo 1.0
 */
function ippo_content_classes() {

	$classes = 'col-sm-12';

	if ( is_active_sidebar( 'sidebar-1' ) && ! ( ippo_is_woocommerce_activated() && ( is_woocommerce() || is_shop() || is_cart() || is_checkout() || is_account_page() ) ) ) {
		$classes = 'col-md-9';
	}

	echo esc_attr( $classes );
}

/**
 * Filter post classes
 *
 * @since Ippo 1.0
 */
function ippo_post_classes( $classes ) {

	if ( is_single() || is_search() || ( is_page() && !is_page_template( 'templates/template-headline.php' || is_page() && !is_page_template( 'templates/template-portfolio.php' ) ) ) )  {

		if ( ippo_is_woocommerce_activated() && is_shop() ) {
			$classes[] = 'hentry';
		}

		return $classes;

	} else {

		// Get blog layout setting
		$blog_layout      = get_theme_mod( 'blog_layout_setting', 'three-columns' );
		$portfolio_layout = get_theme_mod( 'portfolio_layout_setting', 'four-columns' );
		$widget_area_type = get_theme_mod( 'shop_sidebar_settings', 'default' );

		if ( ippo_is_woocommerce_activated() && is_shop() && 'popup' == $widget_area_type ) {
			$classes[] = 'col-lg-3 col-md-4';
		}

		if ( ippo_is_woocommerce_activated() && is_shop() ) {
			$classes[] = 'hentry';
		}

		if ( is_tax( 'ct_portfolio' ) || is_page_template( 'templates/template-portfolio.php' ) || is_post_type_archive('portfolio') ) :

			if ( 'four-columns' == $portfolio_layout ) {

				if ( has_tag( 'spotlight' ) ) {
					$classes[] = 'col-lg-6 col-md-8 col-sm-12';
				} else {
					$classes[] = 'col-lg-3 col-md-4 col-sm-6';
				}

			} else {

				if ( has_tag( 'spotlight' ) ) {
					$classes[] = 'col-md-8 col-sm-12';
				} else {
					$classes[] = 'col-md-4 col-sm-6';
				}

			}

		else :

			if ( 'four-columns' == $blog_layout ) {

				if ( is_active_sidebar( 'sidebar-1' ) ) {

					if ( has_tag( 'spotlight' ) ) {
						$classes[] = 'col-lg-8 col-md-12 col-sm-12';
					} else {
						$classes[] = 'col-lg-4 col-sm-6';
					}

				} else {

					if ( has_tag( 'spotlight' ) ) {
						$classes[] = 'col-lg-6 col-md-8 col-sm-12';
					} else {
						$classes[] = 'col-lg-3 col-md-4 col-sm-6';
					}

				}

			} else {

				if ( is_active_sidebar( 'sidebar-1' ) ) {

					if ( has_tag( 'spotlight' ) ) {
						$classes[] = 'col-sm-12';
					} else {
						$classes[] = 'col-sm-6';
					}

				} else {

					if ( has_tag( 'spotlight' ) ) {
						$classes[] = 'col-md-8 col-sm-12';
					} else {
						$classes[] = 'col-md-4 col-sm-6';
					}

				}

			}

		endif;

		return $classes;

	}

}
add_filter( 'post_class', 'ippo_post_classes', 10, 3 );

/**
 * Display classes for grid sizer helper
 */
function ippo_grid_sizer_class() {

	// Get blog layout setting
	$blog_layout      = get_theme_mod( 'blog_layout_setting', 'three-columns' );
	$portfolio_layout = get_theme_mod( 'portfolio_layout_setting', 'four-columns' );
	$classes          = array();
	$classes[]        = 'grid-sizer';

	if ( is_tax( 'ct_portfolio' ) || is_page_template( 'templates/template-portfolio.php' ) || is_post_type_archive('portfolio')) :

		if ( 'four-columns' == $portfolio_layout ) {
			$classes[] = 'col-lg-3 col-md-4 col-sm-6';
		} else {
			$classes[] = 'col-md-4 col-sm-6';
		}

	else :

		if ( 'four-columns' == $blog_layout ) {

			if ( is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'col-lg-4 col-sm-6';
			} else {
				$classes[] = 'col-lg-3 col-md-4 col-sm-6';
			}

		} else {

			if ( is_active_sidebar( 'sidebar-1' ) ) {
				$classes[] = 'col-sm-6';
			} else {
				$classes[] = 'col-md-4 col-sm-6';
			}

		}

	endif;

	echo esc_attr( implode( ' ', $classes ) );

}

/**
 * Check for embed content in post and extract
 *
 * @since Ippo 1.0
 */
function ippo_get_embeded_media() {
	$content   = get_the_content();
	$embeds    = get_media_embedded_in_content( $content );
	$video_url = wp_extract_urls( $content );

	if ( !empty( $embeds ) ) {


		// Check what is the first embed containg video tag, youtube or vimeo
		foreach( $embeds as $embed ) {
			if ( strpos( $embed, 'video' ) || strpos( $embed, 'youtube' ) || strpos( $embed, 'vimeo' ) || strpos( $embed, 'dailymotion' ) ) {

				$id   = 'ippo-shop' . rand();
				$href = "#TB_inline?height=640&width=1000&inlineId=" . $id;

				if ( !is_single() && has_post_thumbnail() ) {

					$video_url = '<div id="' . $id . '" style="display:none;">' . $embed . '</div>';
					$video_url .= '<figure class="featured-image"><a class="thickbox" title="' . get_the_title() . '" href="' . $href . '">' . get_the_post_thumbnail() . '</a></figure>';

					return $video_url;

				} else {

					return $embed;

				}

			}
		}

	} else {

		if ( $video_url ) {

			if ( strpos( $video_url[0], 'youtube' ) || strpos( $video_url[0], 'vimeo' ) || strpos( $video_url[0], 'dailymotion' ) ) {

				$id   = 'ippo-shop' . rand();
				$href = "#TB_inline?height=640&width=1000&inlineId=" . $id;

				if ( !is_single() && has_post_thumbnail() ) {

					$video_url = '<div id="' . $id . '" style="display:none;">' . wp_oembed_get( $video_url[0] ) . '</div>';
					$video_url .= '<figure class="featured-image"><a class="thickbox" title="' . get_the_title() . '" href="' . $href . '">' . get_the_post_thumbnail() . '</a></figure>';

					return $video_url;

				} else {

					echo wp_oembed_get( esc_html__( $video_url[0] ) );

				}

			}

		} else {
			// No video embedded found
			return $content;
		}
	}
}

/**
 * Filter content for gallery post format
 *
 * @since  Ippo 1.0
 */
function ippo_filter_post_content( $content ) {

	if ( 'video' == get_post_format() && 'post' == get_post_type() ) {
		$video_content = get_media_embedded_in_content( $content );
		$video_url     = wp_extract_urls( $content );

		if ( $video_content ) {
			$content = str_replace( $video_content, '', $content );
		}

		if ( $video_url ) {
			if ( strpos( $video_url[0], 'youtube' ) || strpos( $video_url[0], 'vimeo' ) ) {
				$content = str_replace( $video_url[0], '', $content );
			}
		}

	}

	return $content;
}
add_filter( 'the_content', 'ippo_filter_post_content' );

/**
 * Get Thumbnail Image Size Class
 *
 * @since Ippo 1.0
 */
function ippo_get_featured_image_class() {

	$thumb_class            = '';
	$url                    = wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) );
	list( $width, $height ) = getimagesize( $url );

	if ( $width > $height || $width == $height ) {
		$thumb_class = 'featured-landscape';
	} else {

		if ( '' != get_the_title() ) {
			$thumb_class = 'featured-portrait';
		}
	}

	return $thumb_class;

}

/**
 * Change tag cloud font size
 *
 * @since  Ippo 1.0
 */
function ippo_widget_tag_cloud_args( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'ippo_widget_tag_cloud_args' );

/**
 * Change product tag cloud font size
 *
 * @since  Ippo 1.0
 */
function ippo_woocommerce_tag_cloud_widget() {
	$args = array(
		'largest'  => 12,
		'smallest' => 12,
		'unit'     =>'px',
		'taxonomy' => 'product_tag'
	);
	return $args;
}
add_filter( 'woocommerce_product_tag_cloud_widget_args', 'ippo_woocommerce_tag_cloud_widget' );

/**
 * Remove parenthesses from excerpt
 *
 * @since Ippo 1.0
 */
function ippo_excerpt_more( $more ) {
	return;
}
add_filter( 'excerpt_more', 'ippo_excerpt_more' );

/**
 * Add read more text to excerpt
 *
 * @since Ippo 1.0
 */
function ippo_add_read_more_excerpt( $excerpt ) {
	$read_more_txt = sprintf(
		/* translators: %s: Name of current post. */
		wp_kses( esc_html__( 'Read More', 'ippo-shop' ), array( 'span' => array( 'class' => array() ) ) ),
		the_title( '<span class="screen-reader-text">"', '"</span>', false )
	);

	return $excerpt . '<a class="read-more-link" href=" ' . get_permalink() . ' ">' . $read_more_txt . '</a>';
}
add_filter( 'the_excerpt', 'ippo_add_read_more_excerpt' );

/**
 * Removes parenthesses from category and archives widget
 *
 * @since Ippo 1.0
 */
function ippo_categories_postcount_filter( $variable ) {
	$variable = str_replace( '(', '<span class="post_count"> ', $variable );
	$variable = str_replace( ')', '</span>', $variable );
	return $variable;
}
add_filter( 'wp_list_categories','ippo_categories_postcount_filter' );

function ippo_archives_postcount_filter( $variable ) {
	$variable = str_replace( '(', '<span class="post_count"> ', $variable );
	$variable = str_replace( ')', '</span>', $variable );
	return $variable;
}
add_filter( 'get_archives_link', 'ippo_archives_postcount_filter' );

/**
 * Change related posts thumbnail dimensions
 *
 * @param $thumbnail_size
 * @return mixed
 */
function ippo_jetpack_change_image_size ( $thumbnail_size ) {
	$thumbnail_size['width']  = 350;
	$thumbnail_size['height'] = 250;
	return $thumbnail_size;
}
add_filter( 'jetpack_relatedposts_filter_thumbnail_size', 'ippo_jetpack_change_image_size' );

/**
 * Extract image from video
 */
function ippo_get_video_image( $url, $post_ID, $img_quality ) {

	require_once( ABSPATH . "wp-admin" . '/includes/image.php' );
	require_once( ABSPATH . "wp-admin" . '/includes/file.php' );
	require_once( ABSPATH . "wp-admin" . '/includes/media.php' );

	if ( !empty( $url ) ) {
		$key_str1    = 'youtube';
		$key_str2    = 'vimeo';
		$pos_youtube = strpos( $url, $key_str1 );
		$pos_vimeo   = strpos( $url, $key_str2 );

		if ( !empty( $pos_youtube ) ) {
			$url      = str_replace( 'watch?v=', '', $url );
			$url      = explode( '&', $url );
			$url      = $url[0];
			$protocol = substr( $url, 0, 5 );

			if ( $protocol == "http:" ) {
				$url      = str_replace( 'http://www.youtube.com/', '', $url );
				$protocol_new = "http://";
			}
			if ( $protocol == "https" ) {
				$url      = str_replace( 'https://www.youtube.com/', '', $url );
				$protocol_new = "https://";
			}

			if ( empty( $img_quality ) ) {
				$img_quality = 2;
			}

			$video_image_url = $protocol_new . 'img.youtube.com/vi/'. $url . '/hqdefault.jpg';

			if ( !has_post_thumbnail( $post_ID ) ) {
				$url = $video_image_url;
				$tmp = download_url( $url );

				if( is_wp_error( $tmp ) ){
					// download failed, handle error
				}

				$post_id    = $post_ID;
				$desc       = get_the_title();
				$file_array = array();

				// Set variables for storage
				// fix file filename for query strings
				preg_match( '/[^\?]+\.(jpg|jpe|jpeg|gif|png)/i', $url, $matches );
				$file_array['name']     = basename( $matches[0] );
				$file_array['tmp_name'] = $tmp;

				// If error storing temporarily, unlink
				if ( is_wp_error( $tmp ) ) {
					@unlink( $file_array['tmp_name'] );
					$file_array['tmp_name'] = '';
				}

				// do the validation and storage stuff
				$id = media_handle_sideload( $file_array, $post_id, $desc );

				// If error storing permanently, unlink
				if ( is_wp_error( $id ) ) {
					@unlink( $file_array['tmp_name'] );
					return $id;
				}

				set_post_thumbnail( $post_ID, $id );

			}

			$video_image = get_the_post_thumbnail( $post_ID, 'post-thumbnail', array('class' => 'ippo-video-featured-image skip-lazy') );

		}
		elseif ( !empty( $pos_vimeo ) ) {

			$urlParts = explode( "/", parse_url( $url, PHP_URL_PATH ) );
			$videoId  = (int) $urlParts[count($urlParts)-1 ];
			$data     = wp_remote_get( "http://vimeo.com/api/v2/video/" . $videoId . ".json" );

			if ( !is_wp_error( $data ) && is_array( $data ) ) {
				$data  = wp_remote_get( "http://vimeo.com/api/v2/video/" . $videoId . ".json" );
				$data  = json_decode( wp_remote_retrieve_body( $data ), true );
				$image = $data[0]['thumbnail_large'];

				if ( !has_post_thumbnail( $post_ID ) ) {
					$url = $image;
					$tmp = download_url( $url );

					if( is_wp_error( $tmp ) ){
						// download failed, handle error
					}

					$post_id    = $post_ID;
					$desc       = get_the_title();
					$file_array = array();

					// Set variables for storage
					// fix file filename for query strings
					preg_match( '/[^\?]+\.(jpg|jpe|jpeg|gif|png)/i', $url, $matches );
					$file_array['name']     = basename( $matches[0] );
					$file_array['tmp_name'] = $tmp;

					// If error storing temporarily, unlink
					if ( is_wp_error( $tmp ) ) {
						@unlink( $file_array['tmp_name'] );
						$file_array['tmp_name'] = '';
					}

					// do the validation and storage stuff
					$id = media_handle_sideload( $file_array, $post_id, $desc );

					// If error storing permanently, unlink
					if ( is_wp_error( $id ) ) {
						@unlink( $file_array['tmp_name'] );
						return $id;
					}

					set_post_thumbnail( $post_ID, $id );

				}

				$video_image = get_the_post_thumbnail( $post_ID, 'post-thumbnail', array('class' => 'ippo-video-featured-image skip-lazy') );

			}
		}
		else {

			$video_image = esc_html__( 'Video only allowes vimeo and youtube!', 'ippo-shop' );
		}

		return $video_image;
	}
}

/* Convert hexdec color string to rgb(a) string */

function ippo_hex2rgba( $color, $opacity = false ) {

	$default = 'rgb(0,0,0)';

	//Return default if no color provided
	if ( empty( $color ) ) {
		return $default;
	}

	//Sanitize $color if "#" is provided
	if ( $color[0] == '#' ) {
		$color = substr( $color, 1 );
	}

	//Check if color has 6 or 3 characters and get values
	if ( strlen( $color ) == 6) {
		$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
	} elseif ( strlen( $color ) == 3 ) {
		$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
	} else {
		return $default;
	}

	//Convert hexadec to rgb
	$rgb =  array_map( 'hexdec', $hex );

	//Check if opacity is set(rgba or rgb)
	if ( $opacity ) {
		if ( abs( $opacity ) > 1 ) {
			$opacity = 1.0;
		}
		$output = 'rgba(' . implode( ",", $rgb ) . ',' . $opacity . ')';
	} else {
		$output = 'rgb(' . implode( ",",$rgb ) . ')';
	}

	// Return rgb(a) color string
	return $output;
}

/**
 * Get Instagram Images Feed
 *
 * @since Ippo 1.0
 */
function ippo_get_instagram_feed() {

	$username = get_theme_mod( 'instagram_username' );
	$limit    = 8;
	$link     = '@' . $username;

	if ( $username != '' && class_exists( 'null_instagram_widget' ) ) {

		$instance = array(
		    'title'    => '',
		    'username' => $username,
		    'number'   => $limit,
		    'size'     => 'large',
		    'target'   => '_blank',
		    'link'     => '',
		);

		the_widget('null_instagram_widget', $instance);

	}
	else if ( !class_exists( 'null_instagram_widget' ) ) {
		return esc_html_e( 'Please install "WP Instagram Widget" plugin.', 'ippo-shop' );
	}

	else {
		return esc_html_e( 'Please enter Instagram username to display feed.', 'ippo-shop' );
	}


	if ( $link != '' ) {

		?>

		<div class="container">
			<p class="instagram-username">
				<span><?php esc_html_e( 'Follow', 'ippo-shop' ); ?></span>
				<a href="//instagram.com/<?php echo esc_attr( trim( $username ) ); ?>" rel="me" target="<?php echo esc_attr( $target ); ?>">
					<?php echo esc_html( $link ); ?>
				</a>
			</p>

			<?php

				$instagram_text = get_theme_mod( 'instagram_text' );

				if ( '' != $instagram_text ) {
					printf( '<p class="instagram-description">%s</p>', $instagram_text );
				}

			?>
		</div>

		<?php

	}
}

/**
 * Exclude Category from Blog if slider and category enabled
 *
 * Alters main query to get wanted results
 */
function ippo_exclude_category_from_blog( $query ) {

	// Get Featured Slider settings
	$featured_slider     = get_theme_mod( 'featured_slider_enable', 0 );
	$featured_category   = get_theme_mod( 'featured_category_select', 'default' );
	$featured_slider_cat = get_theme_mod( 'featured_slider_cat_exclude', 0 );

	if ( $featured_slider && $featured_slider_cat ) :

		if ( $query->is_main_query() && $query->is_home() ) {

			if ( 'default' != $featured_category ) {

				$category_exclude    = get_category_by_slug( $featured_category );
				$category_exclude_id = $category_exclude->term_id;

				$query->set( 'category__not_in', array( $category_exclude_id ) );
			}

		}

	endif;

	if ( $query->is_main_query() && $query->is_home() ) {
		if ( $query->is_paged() ) {
			$query->set( 'ignore_sticky_posts', 1 );
		}
	}

}
add_action( 'pre_get_posts', 'ippo_exclude_category_from_blog' );

/**
 * Alter default gallery shortcode output
 */
function ippo_alter_post_gallery( $output, $attr ) {
	global $post;

	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( !$attr['orderby'] )
			unset ($attr['orderby'] );
	}

	extract( shortcode_atts( array(
								 'order'      => 'ASC',
								 'orderby'    => 'menu_order ID',
								 'id'         => $post->ID,
								 'itemtag'    => 'dl',
								 'icontag'    => 'dt',
								 'captiontag' => 'dd',
								 'columns'    => 3,
								 'size'       => 'thumbnail',
								 'include'    => '',
								 'exclude'    => ''
							 ), $attr ) );

	$id = intval( $id );
	if ( 'RAND' == $order ) $orderby = 'none';

	if ( !empty( $include ) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );

		$_attachments = get_posts( array(
									   'include'        => $include,
									   'post_status'    => 'inherit',
									   'post_type'      => 'attachment',
									   'post_mime_type' => 'image',
									   'order'          => $order,
									   'orderby'        => $orderby
								   )
		);

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}
	}

	if ( empty( $attachments ) )
		return '';

	// Here's your actual output, you may customize it to your need
	$output = "<div class=\"entry-gallery fullsize-gallery\">\n";

		$output .= "<div class=\"gallery gallery-size-full\">\n";

			$output .= "<ul class=\"slides list-reset\">\n";

				// Now you loop through each attachment
				foreach ( $attachments as $id => $attachment ) {
					// Get featured image caption
					$thumb_img       = get_post( $id ); 	 // Get post by ID
					$img_title       = $thumb_img->post_title; 	 // Display title
					$img_description = $thumb_img->post_content; // Display Description
					$img             = wp_get_attachment_image_src( $id, 'full' ); // Image src
					$gallery_rel     = get_the_ID() . 'post-gallery';

					$output .= "<figure class=\"gallery-item\">\n";
						$output .= "<a href=\"{$img[0]}\" class=\"thickbox\" data-content=\"{$img_description}\" rel=\"{$gallery_rel}\" title=\"{$img_title}\">";
							$output .= "<img src=\"{$img[0]}\" width=\"{$img[1]}\" height=\"{$img[2]}\" alt=\"gallery image\"  />\n";
						$output .= "</a>";
					$output .= "</figure>\n";
				}

			$output .= "</ul>\n";

		$output .= "</div>\n";

	$output .= "</div>\n";

	return $output;
}
add_filter( 'post_gallery', 'ippo_alter_post_gallery', 10, 2 );

/**
 * Check if WooCommerce is activated
 *
 * @since Ippo 1.0
 */
if ( ! function_exists( 'ippo_is_woocommerce_activated' ) ) {
	function ippo_is_woocommerce_activated() {
		return class_exists( 'woocommerce' ) ? true : false;
	}
}


/**
 * Get title of page that uses portfolio template
 *
 * @return  String [Page title]
 */
function ippo_return_portfolio_page( $type ) {
    $pages = get_pages( array(
        'meta_key'   => '_wp_page_template',
        'meta_value' => 'templates/template-portfolio.php'
    ) );

    if ( !empty( $pages ) ) {
        if ( 'id' == $type ) {
            return $pages[0]->ID;
        } else {
            return $pages[0]->post_title;
        }
    }
}
